@@ -2,10 +2,11 @@ from typing import List, Callable
 from TwitchX.ext.GraphQL import TwitchGraphQL
 from TwitchX.ext.login import TwitchAccount
 from TwitchX.ext.parser import VendorJS
-
+from TwitchX.ext.parser import GQL_CLIENT_ID
 
 __all__: List[Callable] = [
     TwitchGraphQL,
     TwitchAccount,
-    VendorJS
+    VendorJS,
+    GQL_CLIENT_ID
 ]
\ No newline at end of file
